summaryrefslogtreecommitdiff
path: root/lib/coderay/helpers
diff options
context:
space:
mode:
Diffstat (limited to 'lib/coderay/helpers')
-rw-r--r--lib/coderay/helpers/word_list.rb6
1 files changed, 3 insertions, 3 deletions
diff --git a/lib/coderay/helpers/word_list.rb b/lib/coderay/helpers/word_list.rb
index 7f8eba6..ea969c3 100644
--- a/lib/coderay/helpers/word_list.rb
+++ b/lib/coderay/helpers/word_list.rb
@@ -15,7 +15,7 @@ module CodeRay
# WordList is optimized to be used in Scanners,
# typically to decide whether a given ident is a special token.
#
# For case insensitive words use CaseIgnoringWordList.
#
# Example:
#
@@ -60,9 +60,9 @@ module CodeRay
end
# A CaseIgnoringWordList is like a WordList, only that
# keys are compared case-insensitively (normalizing keys using +downcase+).
- class CaseIgnoringWordList < WordList
+ class WordList::CaseIgnoring < WordList
def [] key
super key.downcase
@@ -15,7 +15,7 @@ module CodeRay
# typically to decide whether a given ident is a special token.
#
- # For case insensitive words use CaseIgnoringWordList.
+ # For case insensitive words use WordList::CaseIgnoring.
#
# Example:
@@ -60,9 +60,9 @@ module CodeRay
end
- # A CaseIgnoringWordList is like a WordList, only that
+ # A CaseIgnoring WordList is like a WordList, only that
# keys are compared case-insensitively (normalizing keys using +downcase+).